.. SPDX-FileCopyrightText: Copyright © 2025 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _fairical.usage:

================
 Using Fairical
================

This section describes the various options for producing indicator summary tables, radar
plots, and solution visualisation plots through this library.

.. toctree::
   :maxdepth: 2

   io
   metrics
   cli
   api
   other


.. include:: ../links.rst
